/*
 * Extended from Gabe Ragland implementation https://usehooks.com/useEventListener/
 * to accept multiple events with the same handler and listener options
 */
import { useEffect, useRef } from 'react';
export default function useEventListener(events, handler, elementRef, options) {
  if (options === void 0) {
    options = {};
  }

  // Use window if no element is passed, otherwise default to null in SSR
  var element = elementRef || (typeof window !== 'undefined' ? window : null); // Create a list of events if a single string is passed

  var eventList = Array.isArray(events) ? events : [events];
  var eventListSerialized = eventList.join(); // Create a ref that stores handler

  var savedHandler = useRef(); // Update ref.current value if handler changes.
  // This allows our effect below to always get latest handler ...
  // ... without us needing to pass it in effect deps array ...
  // ... and potentially cause effect to re-run every render.

  useEffect(function () {
    savedHandler.current = handler;
  }, [handler]);
  useEffect(function () {
    // Make sure element supports addEventListener
    var isSupported = element && element.addEventListener;
    if (!isSupported) return;

    var listener = function listener(event) {
      return savedHandler.current(event);
    }; // Add event listener


    eventList.forEach(function (eventName) {
      return element.addEventListener(eventName, listener, options);
    }); // Remove event listener on cleanup

    return function () {
      eventList.forEach(function (eventName) {
        return element.removeEventListener(eventName, listener, options);
      });
    };
  }, [eventListSerialized, element]); // eslint-disable-line react-hooks/exhaustive-deps
}